import React, { useState } from 'react';
import { View, StyleSheet, TouchableOpacity, Text, Image } from 'react-native';
import ActionSheet, { SheetManager } from 'react-native-actions-sheet';
import { useNavigation } from '@react-navigation/native';
import { chatStyles } from './styles';
import { Colors } from 'src/theme';
import { AvatarWithInitials, Input } from 'src/components';
import { API_HOST } from 'src/constants';
import { NAVIGATION_PAGES } from 'src/types';
import { FlashList } from '@shopify/flash-list';

import SearchIcon from 'assets/icons/search.svg';
import { getFontSize } from 'src/utils';

const AllNomadsModal = () => {
  const navigation = useNavigation();
  const [searchQuery, setSearchQuery] = useState('');
  const [data, setData] = useState<any[]>([]);
  const [filteredData, setFilteredData] = useState<any[]>([]);

  const handleSheetOpen = (payload: any) => {
    setData(payload?.members ?? []);
    setFilteredData(payload?.members ?? []);
  };

  const handleSearch = (text: string) => {
    if (text) {
      const searchData =
        data?.filter((item: any) => {
          const itemData = item.name ? item.name.toLowerCase() : ''.toLowerCase();
          const textData = text.toLowerCase();
          return itemData.indexOf(textData) > -1;
        }) ?? [];
      setFilteredData(searchData);
      setSearchQuery(text);
    } else {
      setFilteredData(data);
      setSearchQuery(text);
    }
  };

  const renderItem = ({ item }: { item: any }) => (
    <TouchableOpacity
      style={styles.userItem}
      onPress={() => {
        SheetManager.hide('all-nomads-modal').then(() => {
          navigation.navigate(
            ...([
              NAVIGATION_PAGES.PUBLIC_PROFILE_VIEW,
              {
                userId: item.uid
              }
            ] as never)
          );
        });
      }}
    >
      {item.avatar ? (
        <Image source={{ uri: API_HOST + item.avatar }} style={chatStyles.avatar} />
      ) : (
        <AvatarWithInitials
          text={item.name?.split(' ')[0][0] + item.name?.split(' ')[1][0]}
          flag={API_HOST + item?.flag1}
          size={36}
          fontSize={12}
          borderColor={Colors.LIGHT_GRAY}
          borderWidth={1}
        />
      )}

      <View style={chatStyles.textContainer}>
        <Text style={chatStyles.name}>{item.name}</Text>
      </View>
      {item.admin === 1 && (
        <Text
          style={{
            fontSize: getFontSize(10),
            fontWeight: '600',
            color: Colors.LIGHT_GRAY
          }}
        >
          Admin
        </Text>
      )}
    </TouchableOpacity>
  );

  return (
    <ActionSheet
      id="all-nomads-modal"
      containerStyle={styles.sheetContainer}
      defaultOverlayOpacity={0.5}
      closeOnTouchBackdrop={true}
      keyboardHandlerEnabled={true}
      onBeforeShow={(sheetRef) => {
        const payload = sheetRef || null;
        handleSheetOpen(payload);
      }}
    >
      <View style={styles.container}>
        <TouchableOpacity
          style={styles.header}
          onPress={() => SheetManager.hide('all-nomads-modal')}
        >
          <Text style={chatStyles.cancelText}>Cancel</Text>
        </TouchableOpacity>

        <Input
          inputMode={'search'}
          placeholder={'Search nomads'}
          onChange={handleSearch}
          value={searchQuery}
          icon={<SearchIcon fill={'#C8C8C8'} width={14} height={14} />}
        />

        <FlashList
          viewabilityConfig={{
            waitForInteraction: true,
            itemVisiblePercentThreshold: 50,
            minimumViewTime: 1000
          }}
          data={filteredData || []}
          renderItem={renderItem}
          keyExtractor={(item) => item.uid.toString()}
          estimatedItemSize={100}
          extraData={filteredData}
          showsVerticalScrollIndicator={false}
          contentContainerStyle={{ paddingBottom: 16 }}
        />
      </View>
    </ActionSheet>
  );
};

const styles = StyleSheet.create({
  container: {
    backgroundColor: 'white',
    gap: 16,
    height: '100%'
  },
  sheetContainer: {
    height: '95%',
    borderTopLeftRadius: 15,
    borderTopRightRadius: 15,
    paddingHorizontal: 16
  },
  avatar: {
    width: 30,
    height: 30,
    borderRadius: 15,
    borderWidth: 1,
    borderColor: Colors.LIGHT_GRAY
  },
  header: {
    paddingTop: 16,
    paddingHorizontal: 6,
    width: 68
  },
  userItem: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingVertical: 8,
    paddingHorizontal: 12,
    backgroundColor: Colors.FILL_LIGHT,
    gap: 8,
    borderRadius: 8,
    marginBottom: 6
  }
});

export default AllNomadsModal;
